import * as i18n from 'i18next';
import LanguageDetector from 'i18next-browser-languagedetector';
import { initReactI18next } from 'react-i18next';

import commonEn from './assets/locales/en/common.json';
import commonFr from './assets/locales/fr/common.json';
import Language from './enums/Language';

i18n
  .use(initReactI18next)
  .use(LanguageDetector)
  .init({
    ns: 'common',
    defaultNS: 'common',
    fallbackLng: Language.EN,
    supportedLngs: Object.values(Language), // ['fr', 'en']
    resources: {
      [Language.EN]: {
        common: commonEn,
      },
      [Language.FR]: {
        common: commonFr,
      },
    },
    interpolation: {
      escapeValue: false, // react already safes from xss => https://www.i18next.com/translation-function/interpolation#unescape
    },
    detection: {
      order: ['querystring', 'localStorage'],
      caches: ['localStorage'],
      lookupQuerystring: 'lng',
    },
  });
